@@ -10,7 +10,7 @@ import numpy as np
 from scipy import constants
 from scipy.misc import factorial
 from scipy import integrate
-from .particles import Molecule, MoleculeSTS
+from .particles import MoleculeMultiT, Molecule, MoleculeQuasi, MoleculeOneT
 from . import probabilities as prob
 from .errors import KineticlibError
 from math import exp, gamma, erf
@@ -42,8 +42,8 @@ def crosssection_elastic(g: float, T: float, idata: np.ndarray, rig_sphere: bool
         return raw_crosssection_VSS(g, T, idata[9], idata[10])
 
 
-def crosssection_vt(g: float, T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
-                    rig_sphere: bool=False) -> float:
+def crosssection_vt_fho(g: float, T: float, idata: np.ndarray, molecule: Molecule, i: int, delta: int,
+                        rig_sphere: bool=False) -> float:
     """Calculates the VT crosssection using the FHO probability and VSS or
     rigid sphere cross-section models for the following process: **M(i) + P -> M(i + delta) + P**
 
@@ -55,7 +55,7 @@ def crosssection_vt(g: float, T: float, idata: np.ndarray, molecule: MoleculeSTS
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which undergoes the VT transition
     i : int
         the vibrational level of the molecule undergoing the transition
@@ -76,15 +76,15 @@ def crosssection_vt(g: float, T: float, idata: np.ndarray, molecule: MoleculeSTS
         if ``delta == 0``
     """
     if delta != 0:
-        return raw_crosssection_vt(g, T, idata[1], idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
-                                   molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
-                                   i, delta, rig_sphere)
+        return raw_crosssection_vt_fho(g, T, idata[1], idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
+                                       molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                       i, delta, rig_sphere)
     else:
         raise KineticlibError('VT transition with no change in vibrational level specified')
 
 
-def crosssection_vv(g: float, T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int,
-                    k: int, i_delta: int, rig_sphere: bool=False) -> float:
+def crosssection_vv_fho(g: float, T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule, i: int,
+                        k: int, i_delta: int, rig_sphere: bool=False) -> float:
     """Calculates the VV crosssection using the FHO probability and VSS or
     rigid sphere cross-section models for the following process:
     **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
@@ -97,9 +97,9 @@ def crosssection_vv(g: float, T: float, idata: np.ndarray, molecule1: MoleculeST
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule1 : MoleculeSTS or Molecule
+    molecule1 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule M1
-    molecule2 : MoleculeSTS or Molecule
+    molecule2 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule M2
     i : int
         the vibrational level of molecule M1
@@ -122,14 +122,14 @@ def crosssection_vv(g: float, T: float, idata: np.ndarray, molecule1: MoleculeST
         if ``i_delta == 0``
     """
     if i_delta != 0:
-        return raw_crosssection_vv(g, T, idata[1], idata[0], idata[4], idata[9], idata[10],
-                                   molecule1.vibr[i], molecule1.vibr[i + i_delta],
-                                   molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, rig_sphere)
+        return raw_crosssection_vv_fho(g, T, idata[1], idata[0], idata[4], idata[9], idata[10],
+                                       molecule1.vibr[i], molecule1.vibr[i + i_delta],
+                                       molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, rig_sphere)
     else:
         raise KineticlibError('VV transition with no change in vibrational level specified')
 
 
-def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int,
+def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecule: Molecule, i: int,
                                    center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the dissociation crosssection either using the rigid sphere model or the rigid sphere
     model depending on the relative energy along the center-of-mass line for the process
@@ -148,7 +148,7 @@ def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecu
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : Molecule
+    molecule :  Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     i : int
         the vibrational level from which the molecule dissociates (if ``vl_dependent``
@@ -165,11 +165,11 @@ def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecu
     float
         The dissociation crosssection
     """
-    return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss, center_of_mass,
+    return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss_offset, center_of_mass,
                                               vl_dependent)
 
 
-def min_dimensionless_vel_diss(T: float, molecule: MoleculeSTS, i: int, vl_dependent: bool=True) -> float:
+def min_dimensionless_vel_diss(T: float, molecule: Molecule, i: int, vl_dependent: bool=True) -> float:
     """Calculates the minimum value of the dimensionless relative velocity of colliding particles for which
     the dissociation crosssection is not zero for the process **AB(i) + P -> A + B + P**
 
@@ -177,7 +177,7 @@ def min_dimensionless_vel_diss(T: float, molecule: MoleculeSTS, i: int, vl_depen
     ----------
     T : float
         the temperature of the mixture
-    molecule : Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     i : int
         the vibrational level from which the molecule dissociates (if ``vl_dependent``
@@ -192,11 +192,11 @@ def min_dimensionless_vel_diss(T: float, molecule: MoleculeSTS, i: int, vl_depen
         The minimum value of the dimensionless relative velocity
 
     """
-    return raw_min_dimensionless_vel_diss(T, molecule.vibr[i], molecule.diss, vl_dependent)
+    return raw_min_dimensionless_vel_diss(T, molecule.vibr[i], molecule.diss_offset, vl_dependent)
 
 
-def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
-                rig_sphere: bool=False, nokt: bool=False) -> float:
+def vt_integral_fho(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i: int, delta: int,
+                    rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and VSS or
     rigid sphere cross-section models for the following process: **M(i) + P -> M(i + delta) + P**
 
@@ -208,7 +208,7 @@ def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i:
         the degree of the omega integral
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule :  Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which undergoes the VT transition
     i : int
         the vibrational level of the molecule undergoing the transition
@@ -231,15 +231,16 @@ def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i:
         if ``delta == 0``
     """
     if not rig_sphere:
-        return raw_vt_integral(T, deg, idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
-                               molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
+        return raw_vt_integral_fho(T, deg, idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
+                                   molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
     else:
-        return raw_vt_integral_rigid_sphere(T, deg, idata[1], idata[0], idata[4], molecule.vibr[i],
-                                            molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
+        return raw_vt_integral_rigid_sphere_fho(T, deg, idata[1], idata[0], idata[4], molecule.vibr[i],
+                                                molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                                i, delta, nokt)
 
 
-def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int,
-                k: int, i_delta: int, rig_sphere: bool=False, nokt=False) -> float:
+def vv_integral_fho(T: float, deg: int, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule, i: int,
+                    k: int, i_delta: int, rig_sphere: bool=False, nokt=False) -> float:
     """Calculates the generalized VV omega integral using the FHO probability and VSS or
     rigid sphere cross-section models for the following process:
     **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
@@ -252,9 +253,9 @@ def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, m
         the degree of the omega integral
     idata : 1-D array-like
         the array of interaction data
-    molecule1 : MoleculeSTS or Molecule
+    molecule1 :  Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule M1
-    molecule2 : MoleculeSTS or Molecule
+    molecule2 :  Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule M2
     i : int
         the vibrational level of molecule M1
@@ -279,16 +280,16 @@ def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, m
         if ``i_delta == 0``
     """
     if not rig_sphere:
-        return raw_vv_integral(T, deg, idata[0], idata[4], idata[9], idata[10],
-                               molecule1.vibr[i], molecule1.vibr[i + i_delta],
-                               molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
+        return raw_vv_integral_fho(T, deg, idata[0], idata[4], idata[9], idata[10],
+                                   molecule1.vibr[i], molecule1.vibr[i + i_delta],
+                                   molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
     else:
-        raw_vv_integral_rigid_sphere(T, deg, idata[1], idata[0], idata[4],
-                                     molecule1.vibr[i], molecule1.vibr[i + i_delta],
-                                     molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
+        raw_vv_integral_rigid_sphere_fho(T, deg, idata[1], idata[0], idata[4],
+                                         molecule1.vibr[i], molecule1.vibr[i + i_delta],
+                                         molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
 
 
-def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int,
+def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i: int,
                                center_of_mass: bool=True, vl_dependent: bool=True, nokt: bool=False) -> float:
     """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
     model depending on the relative energy along the center-of-mass line for the process
@@ -302,7 +303,7 @@ def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule:
         the degree of the omega integral
     idata : 1-D array-like
         the array of interaction data
-    molecule : Molecule
+    molecule :  Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     i : int
         the vibrational level from which the molecule dissociates (if ``vl_dependent``
@@ -321,8 +322,8 @@ def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule:
     float
         The generalized omega integral over the dissociation crosssection
     """
-    return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i], molecule.diss, center_of_mass,
-                                          vl_dependent, nokt)
+    return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
+                                          center_of_mass, vl_dependent, nokt)
 
 
 def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=False, nokt: bool=False) -> float:
@@ -350,8 +351,9 @@ def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=Fal
     return raw_elastic_integral(T, deg, idata[1], idata[0], idata[9], idata[10], rig_sphere, nokt)
 
 
-def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule,
-                  rig_sphere: bool=False, nokt: bool=False) -> np.ndarray:
+def vv_collisions_fho(T: float, T1_1: float, T1_2: float, idata: np.ndarray,
+                      molecule1: MoleculeQuasi, molecule2: MoleculeQuasi,
+                      rig_sphere: bool=False, nokt: bool=False) -> np.ndarray:
     """Calculates the averaging :math:`\\left<F \\right>^{VV}_{cd}` over all one-quantum VV crosssections of the type
     **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**,
     (with ``i_delta = 1`` and ``i_delta = -1``) of the following quantities:
@@ -375,14 +377,16 @@ def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecul
     T : float
         the temperature of the mixture
     T1_1 : float
-        the temperature of the first vibrational level of the molecule M1
+        the temperature of the first vibrational level of the molecule M1 (if the one-temperature approximation
+        is used, can be set to any value)
     T1_2 : float
-        the temperature of the first vibrational level of the molecule M2
+        the temperature of the first vibrational level of the molecule M2 (if the one-temperature approximation
+        is used, can be set to any value)
     idata : 1-D array-like
         the array of interaction data
-    molecule1 : Molecule
+    molecule1 : MoleculeMultiT or MoleculeOneT
         the molecule M1
-    molecule2 : Molecule
+    molecule2 : MoleculeMultiT or MoleculeOneT
         the molecule M2
     rig_sphere : bool, optional
         if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
@@ -394,19 +398,36 @@ def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecul
     -------
     np.ndarray
         An array containing the averaged quantities listed above (in the same order)
+
+    Raises
+    KineticlibError
+        If ``molecule1`` are of different ``molecule2``
     
     """
-    a = np.arange(0, molecule1.num_vibr_levels(T, T1_1, True) + 1)
-    b = np.arange(0, molecule2.num_vibr_levels(T, T1_2, True) + 1)
-    vibr_exp = molecule1.vibr_exp(T, T1_1, a)
-    vibr_exp2 = molecule2.vibr_exp(T, T1_2, b)
-    return raw_vv_collisions(T, idata[1], idata[0], idata[4], idata[9], idata[10],
-                             molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
-                             molecule1.vibr, molecule2.vibr, vibr_exp, vibr_exp2,
-                             molecule1.num_vibr, molecule2.num_vibr, rig_sphere, nokt)
+    if isinstance(molecule1, MoleculeMultiT) and isinstance(molecule2, MoleculeMultiT):
+        a = np.arange(0, molecule1.num_vibr_levels(T, T1_1, True) + 1)
+        b = np.arange(0, molecule2.num_vibr_levels(T, T1_2, True) + 1)
+        vibr_exp = molecule1.vibr_exp(T, T1_1, a)
+        vibr_exp2 = molecule2.vibr_exp(T, T1_2, b)
+        return raw_vv_collisions_fho(T, idata[1], idata[0], idata[4], idata[9], idata[10],
+                                     molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
+                                     molecule1.vibr, molecule2.vibr, vibr_exp, vibr_exp2,
+                                     molecule1.num_vibr_levels(T, T1_1, True),
+                                     molecule2.num_vibr_levels(T, T1_2, True), rig_sphere, nokt)
+    elif isinstance(molecule1, MoleculeOneT) and isinstance(molecule2, MoleculeOneT):
+        a = np.arange(0, molecule1.num_vibr + 1)
+        b = np.arange(0, molecule2.num_vibr + 1)
+        vibr_exp = molecule1.vibr_exp(T, a)
+        vibr_exp2 = molecule2.vibr_exp(T, b)
+        return raw_vv_collisions_fho(T, idata[1], idata[0], idata[4], idata[9], idata[10],
+                                     molecule1.Z_vibr(T), molecule2.Z_vibr(T),
+                                     molecule1.vibr, molecule2.vibr, vibr_exp, vibr_exp2,
+                                     molecule1.num_vibr, molecule2.num_vibr, rig_sphere, nokt)
+    else:
+        raise KineticlibError('Types of molecule1 and molecule2 do not match!')
 
 
-def dE_rot_sq(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral: bool=True,
+def dE_rot_sq(T: float, idata: np.ndarray, molecule: Molecule, full_integral: bool=True,
               rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
     over all one-quantum rotational transitions
@@ -420,7 +441,7 @@ def dE_rot_sq(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral:
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which undergoes the rotational energy transition
     full_integral : bool
         if ``True``, the full averaging is calculated, if ``False``, the partial averaging is calculated,
@@ -441,7 +462,7 @@ def dE_rot_sq(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral:
                          molecule.rot_const, molecule.num_rot, full_integral, rig_sphere, nokt)
 
 
-def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral: bool=True,
+def dE_rot_single(T: float, idata: np.ndarray, molecule: Molecule, full_integral: bool=True,
                   rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the change in rotational energy
     over all one-quantum rotational transitions
@@ -455,7 +476,7 @@ def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integ
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which undergoes the rotational energy transition
     full_integral : bool
         if ``True``, the full averaging is calculated, if ``False``,
@@ -477,7 +498,7 @@ def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integ
                              full_integral, rig_sphere, nokt)
 
 
-def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS,
+def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule,
                       full_integral: bool=True, rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the product of changes in rotational energy of two molecules
     over all one-quantum rotational transitions
@@ -492,9 +513,9 @@ def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molec
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule1 : MoleculeSTS or Molecule
+    molecule1 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the first molecule which undergoes the rotational energy transition
-    molecule2 : MoleculeSTS or Molecule
+    molecule2 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the second molecule which undergoes the rotational energy transition
     full_integral : bool
         if ``True``, the full averaging is calculated, if ``False``,
@@ -517,7 +538,7 @@ def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molec
                                  molecule2.num_rot, full_integral, rig_sphere, nokt)
 
 
-def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS,
+def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule,
                        full_integral: bool=True, rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the product of changes in rotational energy of one molecule
     and both molecules over all one-quantum rotational transitions
@@ -534,9 +555,9 @@ def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, mole
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule1 : MoleculeSTS or Molecule
+    molecule1 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the first molecule which undergoes the rotational energy transition
-    molecule2 : MoleculeSTS or Molecule
+    molecule2 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the second molecule which undergoes the rotational energy transition
     full_integral : bool
         if ``True``, the full averaging is calculated, if ``False``,
@@ -596,9 +617,9 @@ def raw_crosssection_rigid_sphere(sigma: float) -> float:
     return constants.pi * (sigma ** 2)
 
 
-def raw_crosssection_vt(g: float, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
-                        ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
-                        delta: int, rig_sphere: bool=False) -> float:
+def raw_crosssection_vt_fho(g: float, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
+                            ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
+                            delta: int, rig_sphere: bool=False) -> float:
     """Calculates the VT crosssection using the FHO probability and VSS or rigid sphere models
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
 
@@ -644,9 +665,9 @@ def raw_crosssection_vt(g: float, T: float, sigma: float, mass: float, beta: flo
                * raw_crosssection_VSS(g, T, vssc, vsso)
 
 
-def raw_crosssection_vv(g, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
-                        ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
-                        i_delta: int, rig_sphere: bool=False) -> float:
+def raw_crosssection_vv_fho(g, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
+                            ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
+                            i_delta: int, rig_sphere: bool=False) -> float:
     """Calculates the VV crosssection using the FHO probability and VSS or rigid sphere models
     for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**, *raw* version
 
@@ -815,9 +836,9 @@ def elastic_omega_g_only_rigid_sphere(g: float, deg: int) -> float:
     return exp(-(g ** 2)) * (g ** (3 + 2 * deg))
 
 
-def raw_vt_integral(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
-                    ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
-                    delta: int, nokt: bool=False) -> float:
+def raw_vt_integral_fho(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
+                        ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
+                        delta: int, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and VSS cross-section models
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
 
@@ -886,9 +907,9 @@ def raw_vt_integral(T: float, deg: int, mass: float, beta: float, vssc: float, v
         raise KineticlibError('VT transition with no change in vibrational level specified')
 
 
-def raw_vt_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float, beta: float,
-                                 ve_before: float, ve_after: float, molecule_vibr_zero: float,
-                                 molecule_diss: float, i: int, delta: int, nokt: bool=False) -> float:
+def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: float, beta: float,
+                                     ve_before: float, ve_after: float, molecule_vibr_zero: float,
+                                     molecule_diss: float, i: int, delta: int, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and rigid sphere
     cross-section models for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
 
@@ -947,9 +968,9 @@ def raw_vt_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float,
         raise KineticlibError('VT transition with no change in vibrational level specified')
 
 
-def raw_vv_integral(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
-                    ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
-                    i_delta: int, nokt=False) -> float:
+def raw_vv_integral_fho(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
+                        ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
+                        i_delta: int, nokt=False) -> float:
     """Calculates the generalized VV omega integral using the FHO probability and VSS cross-section models
     for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**, *raw* version
 
@@ -1017,9 +1038,9 @@ def raw_vv_integral(T: float, deg: int, mass: float, beta: float, vssc: float, v
         raise KineticlibError('VV transition with no change in vibrational level specified')
 
 
-def raw_vv_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float, beta: float, ve_before1: float,
-                                 ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
-                                 i_delta: int, nokt=False) -> float:
+def raw_vv_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: float, beta: float, ve_before1: float,
+                                     ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
+                                     i_delta: int, nokt=False) -> float:
     """Calculates the generalized VV omega integral using the FHO probability and rigid sphere
     cross-section models for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**,
     *raw* version
@@ -1194,12 +1215,12 @@ def raw_elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: fl
         return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (sigma ** 2)
 
 
-def raw_vv_collisions(T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
-                      Z_vibr1: float, Z_vibr2: float,
-                      molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray,
-                      molecule_vibr_exp_array1: np.ndarray, molecule_vibr_exp_array2: np.ndarray,
-                      molecule_num_vibr1: int, molecule_num_vibr2: int, rig_sphere: bool=False,
-                      nokt: bool=False) -> np.ndarray:
+def raw_vv_collisions_fho(T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
+                          Z_vibr1: float, Z_vibr2: float,
+                          molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray,
+                          molecule_vibr_exp_array1: np.ndarray, molecule_vibr_exp_array2: np.ndarray,
+                          molecule_num_vibr1: int, molecule_num_vibr2: int, rig_sphere: bool=False,
+                          nokt: bool=False) -> np.ndarray:
     """Calculates the averaging :math:`\\left<F \\right>^{VV}_{cd}` over all one-quantum VV crosssections of the type
     **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**, (with `i_delta = 1` and `i_delta = -1`)
     of the following quantities:
@@ -1265,14 +1286,14 @@ def raw_vv_collisions(T: float, sigma: float, mass: float, beta: float, vssc: fl
     for k in range(molecule_num_vibr2):
         for i in range(molecule_num_vibr1):
             if not rig_sphere:
-                cs = raw_vv_integral(T, 0, mass, beta, vssc, vsso,
-                                     molecule_vibr_array1[i], molecule_vibr_array1[i + 1],
-                                     molecule_vibr_array2[k + 1], molecule_vibr_array2[k], i, k + 1, 1, nokt)
+                cs = raw_vv_integral_fho(T, 0, mass, beta, vssc, vsso,
+                                         molecule_vibr_array1[i], molecule_vibr_array1[i + 1],
+                                         molecule_vibr_array2[k + 1], molecule_vibr_array2[k], i, k + 1, 1, nokt)
             else:
-                cs = raw_vv_integral_rigid_sphere(T, 0, sigma, mass, beta,
-                                                  molecule_vibr_array1[i], molecule_vibr_array1[i + 1],
-                                                  molecule_vibr_array2[k + 1], molecule_vibr_array2[k],
-                                                  i, k + 1, 1, nokt)
+                cs = raw_vv_integral_rigid_sphere_fho(T, 0, sigma, mass, beta,
+                                                      molecule_vibr_array1[i], molecule_vibr_array1[i + 1],
+                                                      molecule_vibr_array2[k + 1], molecule_vibr_array2[k],
+                                                      i, k + 1, 1, nokt)
             result[0] += ((molecule_vibr_array1[i] -
                            molecule_vibr_array1[i + 1]) ** 2) * molecule_vibr_exp_array1[i]\
                                                               * molecule_vibr_exp_array2[k + 1] * cs
@@ -1305,11 +1326,11 @@ def raw_vv_collisions(T: float, sigma: float, mass: float, beta: float, vssc: fl
             result[11] += molecule_vibr_exp_array1[i] * molecule_vibr_exp_array2[k + 1] * cs
 
             if not rig_sphere:
-                cs = raw_vv_integral(T, 0, mass, beta, vssc, vsso,
+                cs = raw_vv_integral_fho(T, 0, mass, beta, vssc, vsso,
                                      molecule_vibr_array1[i + 1], molecule_vibr_array1[i],
                                      molecule_vibr_array2[k], molecule_vibr_array2[k + 1], i + 1, k, -1, nokt)
             else:
-                cs = raw_vv_integral_rigid_sphere(T, 0, sigma, mass, beta,
+                cs = raw_vv_integral_rigid_sphere_fho(T, 0, sigma, mass, beta,
                                                   molecule_vibr_array1[i + 1], molecule_vibr_array1[i],
                                                   molecule_vibr_array2[k], molecule_vibr_array2[k + 1],
                                                   i + 1, k, -1, nokt)
