@@ -12,7 +12,7 @@ from csv import reader
 from os.path import normcase, join, split
 from scipy import constants
 from .errors import KineticlibError
-from .particles import Particle, MoleculeSTS
+from .particles import Particle, Molecule
 
 
 def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarray:
@@ -86,7 +86,7 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
         return res
 
 
-def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np.ndarray:
+def load_dissociation_parameters(molecule: Molecule, partner: Particle) -> np.ndarray:
     """Loads dissociation model parameters for the Arrhenius model for the reaction
     **Molecule + Partner -> Atom1 + Atom2 + Partner**.
     The model for the equilibrium reaction rate coefficient is considered to be as follows:
@@ -94,7 +94,7 @@ def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np
 
     Parameters
     ----------
-    molecule_name : MoleculeSTS
+    molecule_name : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     partner_name : Particle
         the collision partner
