@@ -9,7 +9,7 @@ __status__ = "Development"
 
 import numpy as np
 from scipy import constants
-from scipy.special import gamma
+from math import gamma, exp
 from scipy.misc import factorial
 from .errors import KineticlibError
 
@@ -494,8 +494,8 @@ def omega_dimensionless_esa(T: float, l: int, r: int, beta: float, eps: float) -
     for i in range(7):
         a[i] = np.dot(coeff_array[i, :], beta_pow_array)
 
-    dimless_omega = (a[0] + a[1] * x) * np.exp((x - a[2]) / a[3]) \
-                                      / (np.exp((x - a[2]) / a[3]) + np.exp((a[2] - x) / a[3]))\
-                    + a[4] * np.exp((x - a[5]) / a[6]) \
-                           / (np.exp((x - a[5]) / a[6]) + np.exp((a[5] - x) / a[6]))
-    return np.exp(dimless_omega)
\ No newline at end of file
+    dimless_omega = (a[0] + a[1] * x) * exp((x - a[2]) / a[3]) \
+                                      / (exp((x - a[2]) / a[3]) + exp((a[2] - x) / a[3]))\
+                    + a[4] * exp((x - a[5]) / a[6]) \
+                           / (exp((x - a[5]) / a[6]) + exp((a[5] - x) / a[6]))
+    return exp(dimless_omega)
\ No newline at end of file
