@@ -119,7 +119,7 @@ class Atom(Particle):
         Particle.__init__(self, name, mass, LJe, LJs, form)
 
 
-class MoleculeSTS(Particle):
+class Molecule(Particle):
     """Molecule class for a state-to-state approximation
     Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
     dissociation-related partition functions, etc.
@@ -156,6 +156,10 @@ class MoleculeSTS(Particle):
         The anharmonic coefficient in the formula for vibrational level energies
     diss : float
         The dissociation energy of the molecule
+    diss_offset : float
+        This is equal to the dissociation energy of the molecule for Molecule and MoleculeOneT instance,
+        for MoleculeMultiT instances this is equal to the dissociation energy of the molecule offset
+        by the energy of the 0-th vibrational level
     rot : ndarray
         The array of rotational energies for each level
     vibr : ndarray
@@ -165,21 +169,6 @@ class MoleculeSTS(Particle):
         the 0th vibrational level in the ``vibr`` array is equal to 0)
     crot : float
         The specific heat capacity of rotational degrees of freedom
-    _current_T : float
-        current flow temperature
-    _current_Z_rot : float
-        current value of the rotational partition function
-    _current_rae : float
-        current value of the averaged rotational energy :math:`\\left<\\varepsilon^{rot} \\right>_{rot}`
-    _current_rae_dimensionless : float
-        current value of the dimensionless averaged rotational energy :math:`\\left<\\varepsilon^{rot} / kT
-        \\right>_{rot}`
-    _current_raesq : float
-        current value of the averaged squared rotational energy :math:`\\left<\\left(\\varepsilon^{rot}\\right)^{2}
-        \\right>_{rot}`
-    _current_raesq_dimensionless : float
-        current value of the averaged squared dimensionless rotational
-        energy :math:`\\left<\\left(\\varepsilon^{rot}/kT\\right)^{2} \\right>_{rot}`
 
     Notes
     -----
@@ -219,6 +208,7 @@ class MoleculeSTS(Particle):
         self.hvc = raw_d[6] * 100 * constants.h * constants.c
         self.avc = raw_d[7]
         self.diss = raw_d[8] * constants.physical_constants['electron volt'][0]
+        self.diss_offset = self.diss
         form = raw_d[9] * constants.physical_constants['electron volt'][0]
         LJe = raw_d[10]  # stored as eps/kboltz
         LJs = raw_d[11] * constants.physical_constants['Angstrom star'][0]
@@ -231,9 +221,8 @@ class MoleculeSTS(Particle):
         self._current_T = 1.0
         self._current_Z_rot = 0.0
         self._current_rae = 0.0
-        self._current_rae_dimensionless = 0.0
         self._current_raesq = 0.0
-        self._current_raesq_dimensionless = 0.0
+        self._current_kT = 1.0
 
         a = np.arange(0, self.num_vibr + 1, 1)
         if self.vibr_model == 'table':
@@ -249,17 +238,18 @@ class MoleculeSTS(Particle):
                 print('File with vibrational energies not found, will use anharmonic oscillator model')
                 self.vibr_model = 'anharmonic'
                 self.vibr_zero = 0.5 * self.hvc * (1 - 0.5 * self.avc * self.hvc)
-                self.vibr[a] = self.hvc * (1.0 - self.avc) * a - self.hvc * self.avc * (a ** 2)
+                self.vibr = self.hvc * (1.0 - self.avc) * a - self.hvc * self.avc * (a ** 2)
 
         elif self.vibr_model == 'anharmonic':
             self.vibr_zero = 0.5 * self.hvc * (1 - 0.5 * self.avc * self.hvc)
-            self.vibr[a] = self.hvc * (1.0 - self.avc) * a - self.hvc * self.avc * (a ** 2)
+            self.vibr = self.hvc * (1.0 - self.avc) * a - self.hvc * self.avc * (a ** 2)
         elif self.vibr_model == 'harmonic':
             self.vibr_zero = 0.5 * self.hvc
-            self.vibr[a] = self.hvc * a
+            self.vibr = self.hvc * a
 
         for j in range(self.num_rot + 1):
             self.rot[j] = j * (j + 1) * self.rot_const
+        self.vibr += self.vibr_zero
 
     def renorm_sts(self, T: float):
         """Calculates all _current values for the molecule
@@ -271,10 +261,9 @@ class MoleculeSTS(Particle):
         """
         self._current_Z_rot = self.Z_rot(T)
         self._current_rae = self.avg_rot_energy(T, True)
-        self._current_rae_dimensionless = self.avg_rot_energy(T, False)
         self._current_raesq = self.avg_rot_energy_sq(T, True)
-        self._current_raesq_dimensionless = self.avg_rot_energy_sq(T, False)
         self._current_T = T
+        self._current_kT = constants.k * T
 
     def vibr_energy(self, i):
         """Returns the energy of the ``i``-th vibrational level :math:`\\varepsilon_{i}`
@@ -401,7 +390,7 @@ class MoleculeSTS(Particle):
             if dimensional:
                 return self._current_rae
             else:
-                return self._current_rae_dimensionless
+                return self._current_rae / self._current_kT
 
     def avg_rot_energy_sq(self, T: float, dimensional: bool=True) -> float:
         """
@@ -436,7 +425,7 @@ class MoleculeSTS(Particle):
             if dimensional:
                 return self._current_raesq
             else:
-                return self._current_raesq_dimensionless
+                return self._current_raesq / self._current_kT
 
     def Z_vibr_eq(self, T: float, model: str='none') -> float:
         """Returns the equilibrium vibrational partition function :math:`Z_{eq}(T)` (which is used in various
@@ -512,114 +501,59 @@ class MoleculeSTS(Particle):
                    * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
 
 
-class Molecule(MoleculeSTS):
+class MoleculeQuasi(Molecule):
+    """Molecule class for quasi-stationary approximations
+    Used for type annotations, adds some internal things compared to the Molecule class, but other than that,
+    is full identical
+
+    Notes
+    -----
+    Attributes whose names begin with `_current_` are not meant to be accessed directly, as doing so may lead to errors,
+    they are calculated when the `renorm_sts` method is called, and are correct only if the current flow temperature
+    is the same as the temperature which was passed to the `renorm_sts` method
+    The energy of the 0th vibrational level is set to 0, the non-zero value is stored in the vibr_zero field
+    """
+    def __init__(self, name, vmodel='anharmonic'):
+        """Creates a new molecule
+
+        Parameters
+        ----------
+        name : str
+            The name of the molecule ('N2', 'NO', etc.)
+        vmodel : str
+            The model to be used for the vibrational spectrum, possible values:
+                * 'harmonic'
+                * 'anharmonic'
+                * 'table' (if 'table' is used and no file containing the energy values is found, the
+                  'anharmonic' model will be used)
+
+            defaults to 'anharmonic'
+        """
+        Molecule.__init__(self, name, vmodel)
+
+        self._current_Z_vibr = 0.0
+        self._current_n = 0.0
+        self._current_ni = np.zeros(self.num_vibr + 1)
+        self._current_v_exp = np.zeros(self.num_vibr + 1)
+        self._current_edt = 0.0
+        self._current_zdt = 0.0
+        self._current_vae = 0.0
+        self._current_vae_dimensionless = 0.0
+        self._current_vaesq = 0.0
+        self._current_vaesq_dimensionless = 0.0
+        self._current_edt = 0.0
+
+        self._current_kT = 0.0
+
+
+class MoleculeMultiT(MoleculeQuasi):
     """Molecule class for a multi-temperature approximation
     Builds upon the MoleculeSTS class, and provides additional methods concerning vibrational partition functions,
     their derivatives, etc.
 
     Attributes
     ----------
-    name : str
-        The name of the particle
-    mass : float
-        The mass of the particle
-    LJe : float
-        The particle Lennard-Jones varepsilon parameter (stored as varepsilon / k)
-    LJs : float
-        The particle Lennard-Jones sigma parameter (the particle radius)
-    form : float
-        The formation energy of the particle
-    vibr_model : str
-        The model of the vibrational spectrum (can be either 'harmonic', 'anharmonic' or 'table', if pre-calculated
-        table values are used for each vibrational level)
-    rot_symmetry : float
-        The rotational symmetry factor (equal to 2.0 if the molecule is homonuclear and to 1.0 otherwise)
-    num_rot : int
-        The number of rotational levels in the molecule
-    num_vibr : int
-        The number of vibrational levels in the molecule
-    inertia : float
-        The moment of rotational inertia :math:`I_{rot,c}`
-    rot_const : float
-        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
-        inertia
-    hvc : float
-        The harmonic coefficient in the formula for vibrational level energies
-    avc : float
-        The anharmonic coefficient in the formula for vibrational level energies
-    diss : float
-        The dissociation energy of the molecule
-    rot : ndarray
-        The array of rotational energies for each level
-    vibr : ndarray
-        The array of vibrational energies for each level
-    vibr_zero : float
-        The energy of the 0th vibrational level (stored separately as the value of the energy of
-        the 0th vibrational level in the ``vibr`` array is equal to 0)
-    crot : float
-        The specific heat capacity of rotational degrees of freedom
-    _current_T : float
-        current flow temperature
-    _current_T1 : float
-        current temperature of the first vibrational level T_{1} of the particular molecular species
-    _current_Z_rot : float
-        current value of the rotational partition function
-    _current_Z_vibr : float
-        current vibrational partition function
-    _current_rae : float
-        current value of the averaged rotational energy :math:`\\left<\\varepsilon^{rot} \\right>_{rot}`
-    _current_rae_dimensionless : float
-        current value of the dimensionless averaged rotational energy :math:`\\left<\\varepsilon^{rot} / kT
-        \\right>_{rot}`
-    _current_raesq : float
-        current value of the averaged squared rotational energy :math:`\\left<\\left(\\varepsilon^{rot}\\right)^{2}
-        \\right>_{rot}`
-    _current_raesq_dimensionless : float
-        current value of the averaged squared dimensionless rotational
-        energy :math:`\\left<\\left(\\varepsilon^{rot}/kT\\right)^{2} \\right>_{rot}`
-    _current_vae : float
-        current value of the vibrational energy averaged over the vibrational spectrum
-        :math:`\\left<\\varepsilon^{vibr} \\right>_{vibr}`
-    _current_vae_dimensionless : float
-        current value of the dimensionless vibrational energy averaged over the vibrational spectrum
-        :math:`\\left<\\varepsilon^{vibr} / kT \\right>_{vibr}`
-    _current_vaesq : float
-        current value of the averaged squared vibrational energy
-        :math:`\\left<\\left(\\varepsilon^{vibr}\\right)^{2} \\right>_{vibr}`
-    _current_vaesq_dimensionless : float
-        current value of the averaged squared dimensionless vibrational energy
-        :math:`\\left<\\left(\\varepsilon^{vibr}/kT\\right)^{2} \\right>_{vibr}`
-    _current_vae_i : float
-        current value of the following quantity: :math:`\\left<i\\varepsilon^{vibr}_{i}\\right>_{vibr}`
-    _current_vae_i_dimensionless :
-        current value of the following quantity: :math:`\\left<i\\varepsilon^{vibr}_{i} / kT\\right>_{vibr}`
-    _current_n : float
-        current numeric density of the particular species
-    _current_ni - ndarray
-        containing the _current densities of the particular species at each vibrational level
-    _current_v_exp : ndarray
-        array containing the current vibrational exponents
-    _current_avg_i : float
-        current value of the following quantity: :math:`\\left<i\\right>_{vibr}`
-    _current_avg_i_sq : float
-        current value of the following quantity: :math:`\\left<i^{2}\\right>_{vibr}`
-    _current_wdt : float
-        current derivative of average amount of vibrational quanta per unit of mass of the particular species
-        with respect to the temperature T
-    _current_wdt1 : float
-        current derivative of average amount of vibrational quanta per unit of mass of the particular species
-        with respect to the temperature of the first vibrational level :math:`T_{1}`
-    _current_edt : float
-        current derivative of vibrational energy per unit of mass of the particular species
-        with respect to the temperature T
-    _current_edt1 : float
-        current derivative of vibrational energy per unit of mass of the particular species
-        with respect to the temperatute of the first vibrational level :math:`T_{1}`
-    _current_zdt : float
-        current derivative of vibrational partition function with respect to the temperature T
-    _current_zdt1 : float
-        current derivative of vibrational partition function with respect to the temperature of the first
-        vibrational level :math:`T_{1}`
+    See ``Molecule`` class
 
     Notes
     -----
@@ -644,7 +578,7 @@ class Molecule(MoleculeSTS):
 
             defaults to 'anharmonic'
         """
-        MoleculeSTS.__init__(self, name, vmodel)
+        MoleculeQuasi.__init__(self, name, vmodel)
 
         self.max_vibr = self.num_vibr
         self._current_T1 = 1.0
@@ -657,7 +591,6 @@ class Molecule(MoleculeSTS):
         self._current_avg_i_sq = 0.0
         self._current_wdt = 0.0
         self._current_wdt1 = 0.0
-        self._current_edt = 0.0
         self._current_edt1 = 0.0
         self._current_zdt = 0.0
         self._current_zdt1 = 0.0
@@ -667,6 +600,8 @@ class Molecule(MoleculeSTS):
         self._current_vaesq_dimensionless = 0.0
         self._current_vae_i = 0.0
         self._current_vae_i_dimensionless = 0.0
+        self.vibr -= self.vibr_zero
+        self.diss_offset -= self.vibr_zero
 
     def renorm(self, T: float, T1: float, n_c: float):
         """Calculates all _current values for the molecule
@@ -684,9 +619,7 @@ class Molecule(MoleculeSTS):
 
         self._current_Z_rot = self.Z_rot(T)
         self._current_rae = self.avg_rot_energy(T, True)
-        self._current_rae_dimensionless = self.avg_rot_energy(T, False)
         self._current_raesq = self.avg_rot_energy_sq(T, True)
-        self._current_raesq_dimensionless = self.avg_rot_energy_sq(T, False)
 
         self._current_Z_vibr = self.Z_vibr(T, T1)
         self._current_Z_int = self.Z_int(T, T1)
@@ -1047,7 +980,7 @@ class Molecule(MoleculeSTS):
             return self._current_zdt1
 
     def W_dT(self, T: float, T1: float) -> float:
-        """Returns the partial derivative of the average number of vibrational quanta per unit of mass :math:`W` with
+        """Returns the partial derivative of the average number of vibrational quanta per unit mass :math:`W` with
         respect to the temperature :math:`T`
 
         Parameters
@@ -1060,7 +993,7 @@ class Molecule(MoleculeSTS):
         Returns
         -------
         float
-            The partial derivative of the average number of vibrational quanta per unit of mass with respect to
+            The partial derivative of the average number of vibrational quanta per unit mass with respect to
             the temperature :math:`T`
         """
         if self.vibr_model == 'harmonic':
@@ -1074,7 +1007,7 @@ class Molecule(MoleculeSTS):
                 return self._current_wdt
 
     def W_dT1(self, T: float, T1: float) -> float:
-        """Returns the partial derivative of the average number of vibrational quantaper unit of mass :math:`W` with
+        """Returns the partial derivative of the average number of vibrational quantaper unit mass :math:`W` with
         respect to the temperature of the first vibrational level :math:`T_{1}`
 
         Parameters
@@ -1087,7 +1020,7 @@ class Molecule(MoleculeSTS):
         Returns
         -------
         float
-            The partial derivative of the average number of vibrational quanta per unit of mass with respect to
+            The partial derivative of the average number of vibrational quanta per unit mass with respect to
             the temperature of the first vibrational level :math:`T_{1}`
         """
         if (self._current_T != T) or (self._current_T1 != T1):
@@ -1097,7 +1030,7 @@ class Molecule(MoleculeSTS):
             return self._current_wdt1
 
     def E_vibr(self, T: float, T1: float) -> float:
-        """Returns the full vibrational energy per unit of mass :math:`E_{vibr}` (which is equal to the averaged
+        """Returns the full vibrational energy per unit mass :math:`E_{vibr}` (which is equal to the averaged
         vibrational energy divided by the molecule mass)
 
         Parameters
@@ -1110,12 +1043,12 @@ class Molecule(MoleculeSTS):
         Returns
         -------
         float
-            The full vibrational energy per unit of mass
+            The full vibrational energy per unit mass
         """
         return self.avg_vibr_energy(T, T1) / self.mass
 
     def E_vibr_dT(self, T: float, T1: float) -> float:
-        """Returns the partial derivative of the full vibrational energy per unit of mass :math:`E_{vibr}` with respect
+        """Returns the partial derivative of the full vibrational energy per unit mass :math:`E_{vibr}` with respect
         to the temperature :math:`T`
 
         Parameters
@@ -1128,7 +1061,7 @@ class Molecule(MoleculeSTS):
         Returns
         -------
         float
-            The partial derivative of the full vibrational energy per unit of mass with respect to the temperature
+            The partial derivative of the full vibrational energy per unit mass with respect to the temperature
             :math:`T`
         """
         if (self._current_T != T) or (self._current_T1 != T1):
@@ -1142,7 +1075,7 @@ class Molecule(MoleculeSTS):
             return self._current_edt
 
     def E_vibr_dT1(self, T: float, T1: float) -> float:
-        """Returns the partial derivative of the full vibrational energy per unit of mass :math:`E_{vibr}` with respect
+        """Returns the partial derivative of the full vibrational energy per unit mass :math:`E_{vibr}` with respect
         to the temperature of the first vibrational level :math:`T_{1}`
 
         Parameters
@@ -1155,11 +1088,280 @@ class Molecule(MoleculeSTS):
         Returns
         -------
         float
-            The partial derivative of the full vibrational energy per unit of mass with respect to the temperature
+            The partial derivative of the full vibrational energy per unit mass with respect to the temperature
             of the first vibrational level :math:`T_{1}`
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             return (self.avg_vibr_energy_i(T, T1) - self.avg_i(T, T1) * self.avg_vibr_energy(T, T1))\
                     * self.vibr[1] / (constants.k * T1 * T1 * self.mass)
         else:
-            return self._current_edt1
\ No newline at end of file
+            return self._current_edt1
+
+
+class MoleculeOneT(MoleculeQuasi):
+    """Molecule class for a state-to-state approximation
+    Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
+    dissociation-related partition functions, etc.
+
+    Attributes
+    ----------
+    See ``Molecule`` class
+
+    Notes
+    -----
+    Attributes whose names begin with `_current_` are not meant to be accessed directly, as doing so may lead to errors,
+    they are calculated when the `renorm_sts` method is called, and are correct only if the current flow temperature
+    is the same as the temperature which was passed to the `renorm_sts` method
+    The energy of the 0th vibrational level is set to 0, the non-zero value is stored in the vibr_zero field
+    """
+    def __init__(self, name, vmodel='anharmonic'):
+        """Creates a new molecule
+
+        Parameters
+        ----------
+        name : str
+            The name of the molecule ('N2', 'NO', etc.)
+        vmodel : str
+            The model to be used for the vibrational spectrum, possible values:
+                * 'harmonic'
+                * 'anharmonic'
+                * 'table' (if 'table' is used and no file containing the energy values is found, the
+                  'anharmonic' model will be used)
+
+            defaults to 'anharmonic'
+        """
+        MoleculeQuasi.__init__(self, name, vmodel)
+
+    def renorm(self, T: float, n_c: float):
+        """Calculates all _current values for the molecule
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        n_c : float
+            the numeric density of the molecular species
+        """
+        self._current_Z_rot = self.Z_rot(T)
+        self._current_rae = self.avg_rot_energy(T, True)
+        self._current_raesq = self.avg_rot_energy_sq(T, True)
+
+        self._current_Z_vibr = self.Z_vibr(T)
+        self._current_vae = self.avg_vibr_energy(T, True)
+        self._current_vaesq = self.avg_vibr_energy_sq(T, True)
+
+        a = np.arange(0, self.num_vibr + 1, 1)
+        self._current_v_exp = self.vibr_exp(T, a)
+        self._current_ni = self.ni(T, a, n_c)
+        self._current_n = n_c
+
+        self._current_T = T
+        self._current_kT = constants.k * T
+
+    def vibr_exp(self, T: float, i):
+        """Returns the vibrational exponent: :math:`\\exp(-\\varepsilon_{i} / kT)`
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        i : int or 1-D array-like
+            the number of the level (or a an array/list of level numbers) for which to return the vibrational exponent
+        zero_level : bool
+            if ``True``, the energy of the vibrational energies are not counted from zero (and the energy of the 0-the
+            vibrational level is not equal to zero), if ``False``,
+            the energy of the vibrational energies are counted from zero (and the energy of the 0-th vibrational level
+            is equal to zero), defaults to ``True``
+
+        Returns
+        -------
+        float or 1-D np.ndarray
+            The vibrational exponent for a given index or set of indices `i`
+        """
+        if self._current_T != T:
+            return np.exp(-self.vibr[i] / (T * constants.k))
+        else:
+            return self._current_v_exp[i]
+
+    def Z_vibr(self, T: float) -> float:
+        """Returns the vibrational partition function :math:`Z_{vibr}(T)`
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+
+        Returns
+        -------
+        float
+            The vibrational partition function
+        """
+        if self._current_T != T:
+            return self.vibr_exp(T, np.arange(0, self.num_vibr + 1, 1)).sum()
+        else:
+            return self._current_Z_vibr
+
+    def Z_int(self, T: float) -> float:
+        """Returns the internal partition function :math:`Z_{int}(T) = Z_{rot}(T) Z_{vibr}(T)`
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+
+        Returns
+        -------
+        float
+            The vibrational partition function
+        """
+        if self._current_T != T:
+            return self.Z_rot(T) * self.Z_vibr(T)
+        else:
+            return self._current_Z_rot * self._current_Z_vibr
+
+    def avg_vibr_energy(self, T: float, dimensional: bool=True) -> float:
+        """Returns the vibrational energy averaged over the vibrational spectrum (either dimensional
+        :math:`\\left<\\varepsilon^{vibr} \\right>_{vibr}` or dimensionless
+        :math:`\\left<\\varepsilon^{vibr} / kT \\right>_{vibr}`)
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        dimensional : bool
+            if True, the dimensional averaged vibrational energy is returned, if False, the dimensionless averaged
+            vibrational energy is returned, defaults to True
+
+        Returns
+        -------
+        float
+            The averaged vibrational energy
+        """
+        if self._current_T != T:
+            a = np.arange(0, self.num_vibr + 1, 1)
+            if dimensional:
+                return np.dot(self.vibr_exp(T, a), self.vibr[a]) / self.Z_vibr(T)
+            else:
+                return np.dot(self.vibr_exp(T, a), self.vibr[a]
+                              / (constants.k * T)) / self.Z_vibr(T)
+        else:
+            if dimensional:
+                return self._current_vae
+            else:
+                return self._current_vae / self._current_kT
+
+    def avg_full_energy(self, T: float, dimensional: bool=True) -> float:
+        """Returns the full internal energy averaged over the internal spectrum (either dimensional
+        :math:`\\left<\\varepsilon^{int} \\right>_{int}` or dimensionless
+        :math:`\\left<\\varepsilon^{int} / kT \\right>_{int}`)
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        dimensional : bool
+            if True, the dimensional averaged internall energy is returned, if False, the dimensionless averaged
+            internal energy is returned, defaults to True
+
+        Returns
+        -------
+        float
+            The averaged internal energy
+        """
+        return self.avg_vibr_energy(T, dimensional) + self.avg_rot_energy(T, dimensional)
+
+    def avg_vibr_energy_sq(self, T: float, dimensional: bool=True) -> float:
+        """Returns the squared vibrational energy averaged over the vibrational spectrum (either dimensional
+        :math:`\\left<\\left(\\varepsilon^{vibr} \\right)^{2}\\right>_{vibr}`
+        or dimensionless :math:`\\left<\\left(\\varepsilon^{vibr} / kT \\right)^{2}\\right>_{vibr}`)
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        dimensional : bool
+            if True, the averaged squared dimensional vibrational energy is returned, if False, the averaged squared
+            dimensionless vibrational energy is returned, defaults to True
+
+        Returns
+        -------
+        float
+            The averaged squared vibrational energy
+        """
+        if self._current_T != T:
+            a = np.arange(0, self.num_vibr + 1, 1)
+            if dimensional:
+                return np.dot(self.vibr_exp(T, a), np.power(self.vibr[a], 2))\
+                       / self.Z_vibr(T)
+            else:
+                return np.dot(self.vibr_exp(T, a), np.power(self.vibr[a]
+                                                                  / (constants.k * T), 2)) / self.Z_vibr(T)
+            # else:
+            #     if dimensional:
+            #         return np.dot(self.vibr_exp(T, a, False), np.power(self.vibr[a], 2)) / self.Z_vibr(T, False)
+            #     else:
+            #         return np.dot(self.vibr_exp(T, a, False), np.power(self.vibr[a]
+            #                       / (constants.k * T), 2)) / self.Z_vibr(T, False)
+        else:
+            if dimensional:
+                return self._current_vaesq
+            else:
+                return self._current_vaesq / (self._current_kT ** 2)
+
+    def ni(self, T: float, i, n_c: float):
+        """Returns the numeric density of the ``i``-th vibrational level :math:`n_{i}` for the molecular species
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        i : int or 1-D array-like
+            the number of the level (or a an array/list of level numbers) for which to return the numeric densities
+        n_c : float
+            the numeric density of the molecular species
+
+        Returns
+        -------
+        float or 1-D np.ndarray
+            The numeric density for a given index or set of indices `i`
+        """
+        if (self._current_T != T) or (self._current_n != n_c):
+            return n_c * self.vibr_exp(T, i) / self.Z_vibr(T)
+        else:
+            return self._current_ni[i]
+
+    def E_vibr(self, T: float) -> float:
+        """Returns the full vibrational energy per unit mass :math:`E_{vibr}` (which is equal to the averaged
+        vibrational energy divided by the molecule mass)
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+
+        Returns
+        -------
+        float
+            The full vibrational energy per unit mass
+        """
+        return self.avg_vibr_energy(T) / self.mass
+
+    def E_vibr_dT(self, T: float) -> float:
+        """Returns the partial derivative of the full vibrational energy per unit mass :math:`E_{vibr}` with respect
+        to the temperature :math:`T`
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+
+        Returns
+        -------
+        float
+            The partial derivative of the full vibrational energy per unit mass with respect to the temperature
+            :math:`T`
+        """
+        if self._current_T != T:
+            return -1  # TODO
+        else:
+            return self._current_edt
\ No newline at end of file
