@@ -9,11 +9,11 @@ __status__ = "Production"
 import numpy as np
 from scipy import constants
 from .crosssection import raw_diss_integral_rigid_sphere
-from .particles import MoleculeSTS, Molecule, Atom
+from .particles import Molecule, MoleculeMultiT, Atom, MoleculeOneT, MoleculeQuasi
 from math import exp
 
 
-def k_diss_eq(T: float, model_data: np.ndarray, molecule_diss: float) -> float:
+def k_diss_eq(T: float, model_data: np.ndarray, molecule: Molecule) -> float:
     """Calculates the equilibrium dissociation rate constant using the Arrhenius model
 
     Parameters
@@ -22,8 +22,8 @@ def k_diss_eq(T: float, model_data: np.ndarray, molecule_diss: float) -> float:
         the temperature of the mixture
     model_data : 1-D array-like
         dissociation model data
-    molecule_diss : float
-        the dissociation energy of the molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
+        the molecule which dissociates
 
     Returns
     -------
@@ -31,10 +31,10 @@ def k_diss_eq(T: float, model_data: np.ndarray, molecule_diss: float) -> float:
         Equilibrium dissociation rate constant
 
     """
-    return raw_k_diss_eq(T, model_data[0], model_data[1], molecule_diss)
+    return raw_k_diss_eq(T, model_data[0], model_data[1], molecule.diss)
 
 
-def diss_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: MoleculeSTS, i: int,
+def diss_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Molecule, i: int,
                                   model: str='D6k') -> float:
     """Calculates the state-to-state non-equilibrium dissociation rate constant using the Treanor-Marrone model
 
@@ -44,7 +44,7 @@ def diss_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mo
         the temperature of the mixture
     model_data : 1-D array-like
         dissociation model data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     i : int
         the vibrational level from which the molecule dissociates
@@ -69,7 +69,7 @@ def diss_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mo
                                              molecule.diss)
 
 
-def diss_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int,
+def diss_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule, i: int,
                                center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the state-to-state non-equilibrium dissociation rate constant using the rigid-sphere crosssection
 
@@ -79,7 +79,7 @@ def diss_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: MoleculeST
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     i : int
         the vibrational level from which the molecule dissociates (if ``vl_dependent``
@@ -97,11 +97,11 @@ def diss_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: MoleculeST
     float
         Non-equilibrium dissociation state-to-state rate constant
     """
-    return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss, center_of_mass,
-                                          vl_dependent)
+    return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
+                                          center_of_mass, vl_dependent)
 
 
-def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: MoleculeSTS, atom1: Atom, atom2: Atom,
+def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom,
                                  i: int, model: str='D6k') -> float:
     """Calculates the state-to-state recombination rate constant using the Treanor-Marrone model
 
@@ -111,7 +111,7 @@ def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mol
         the temperature of the mixture
     model_data : 1-D array-like
         dissociation model data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     atom1 : Atom
         atom of the first atomic species which make up the molecule
@@ -140,7 +140,7 @@ def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mol
                                             molecule.vibr[i], molecule.diss)
 
 
-def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: MoleculeSTS, atom1: Atom, atom2: Atom, i: int,
+def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom, i: int,
                               center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the state-to-state recombination rate constant using the rigid-sphere crosssection
 
@@ -150,7 +150,7 @@ def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: MoleculeSTS
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which dissociates
     atom1 : Atom
         atom of the first atomic species which make up the molecule
@@ -173,10 +173,11 @@ def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: MoleculeSTS
         Recombination state-to-state rate constant
     """
     return raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                         atom2.mass, molecule.vibr[i], molecule.diss, center_of_mass, vl_dependent)
+                                         atom2.mass, molecule.vibr[i], molecule.diss_offset,
+                                         center_of_mass, vl_dependent)
 
 
-def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: Molecule,
+def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
                               model: str='D6k') -> float:
     """Calculates the multi(one)-temperature non-equilibrium dissociation rate constant using the Treanor-Marrone model
 
@@ -188,7 +189,7 @@ def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molec
         the temperature of the first vibrational level of the molecule which dissociates
     model_data : 1-D array-like
         dissociation model data
-    molecule : Molecule
+    molecule : MoleculeMultiT or MoleculeOneT
         the molecule which dissociates
     model : str
         the model for the `U` parameter to be used, possible values:
@@ -207,14 +208,21 @@ def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molec
         Non-equilibrium dissociation rate constant
     """
     res = 0.0
-    for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-        res += molecule.vibr_exp(T, T1, i) \
-               * raw_diss_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
-                                                   molecule.Z_diss(T, i, model), molecule.diss)
-    return res / molecule.Z_vibr(T, T1)
+    if isinstance(molecule, MoleculeMultiT):
+        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+            res += molecule.vibr_exp(T, T1, i) \
+                   * raw_diss_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
+                                                       molecule.Z_diss(T, i, model), molecule.diss)
+        return res / molecule.Z_vibr(T, T1)
+    else:
+        for i in range(molecule.num_vibr + 1):
+            res += molecule.vibr_exp(T, i) \
+                   * raw_diss_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
+                                                       molecule.Z_diss(T, i, model), molecule.diss)
+        return res / molecule.Z_vibr(T)
 
 
-def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Molecule,
+def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi,
                            center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the multi(one)-temperature non-equilibrium dissociaiton rate constant using the
     rigid-sphere crosssection
@@ -227,7 +235,7 @@ def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mol
         the temperature of the first vibrational level of the molecule which dissociates
     idata : 1-D array-like
         the array of interaction data
-    molecule : Molecule
+    molecule : MoleculeMultiT or MoleculeOneT
         the molecule which dissociates
     center_of_mass : bool, optional
         if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
@@ -243,14 +251,22 @@ def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mol
         Non-equilibrium dissociation rate constant
     """
     res = 0.0
-    for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-        res += molecule.vibr_exp(T, T1, i) \
-               * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss, center_of_mass,
-                                                vl_dependent)
-    return res / molecule.Z_vibr(T, T1)
+    if isinstance(molecule, MoleculeMultiT):
+        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+            res += molecule.vibr_exp(T, T1, i) \
+                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
+                                                    center_of_mass, vl_dependent)
+        return res / molecule.Z_vibr(T, T1)
+    else:
+        for i in range(molecule.num_vibr + 1):
+            res += molecule.vibr_exp(T, i) \
+                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
+                                                    center_of_mass, vl_dependent)
+        return res / molecule.Z_vibr(T)
 
 
-def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom) -> float:
+def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: MoleculeQuasi,
+                             atom1: Atom, atom2: Atom) -> float:
     """Calculates the averaged recombination rate constant using the Treanor-Marrone model
 
     Parameters
@@ -259,7 +275,7 @@ def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: Molecul
         the temperature of the mixture
     model_data : 1-D array-like
         dissociation model data
-    molecule : MoleculeSTS or Molecule
+    molecule : MoleculeMultiT or MoleculeOneT
         the molecule which dissociates
     atom1 : Atom
         atom of the first atomic species which make up the molecule
@@ -271,11 +287,15 @@ def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: Molecul
     float
         Averaged recombination rate constant
     """
-    return raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T, T),
-                                        molecule.mass, atom1.mass, atom2.mass, molecule.diss)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T, T),
+                                            molecule.mass, atom1.mass, atom2.mass, molecule.diss)
+    else:
+        return raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T),
+                                            molecule.mass, atom1.mass, atom2.mass, molecule.diss)
 
 
-def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom,
+def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom,
                           center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the averaged recombination rate constant using the rigid-sphere crosssection
 
@@ -287,7 +307,7 @@ def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mole
         the temperature of the first vibrational level of the molecule which dissociates
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : MoleculeMultiT or MoleculeOneT
         the molecule which dissociates
     atom1 : Atom
         atom of the first atomic species which make up the molecule
@@ -306,11 +326,17 @@ def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mole
     float
         Averaged recombination rate constant
     """
-    res = 0.0
-    for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-        res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                             atom2.mass, molecule.vibr[i], molecule.diss,
-                                             center_of_mass, vl_dependent)
+    res = 0.0  # TODO - maybe this can be cleaned up?
+    if isinstance(molecule, MoleculeMultiT):
+        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+            res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                                 atom2.mass, molecule.vibr[i], molecule.diss_offset,
+                                                 center_of_mass, vl_dependent)
+    else:
+        for i in range(molecule.num_vibr + 1):
+            res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                                 atom2.mass, molecule.vibr[i], molecule.diss_offset,
+                                                 center_of_mass, vl_dependent)
     return res
 
 
