@@ -7,12 +7,12 @@ __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
 
 
-from .crosssection import raw_vv_integral, raw_vt_integral, raw_vt_integral_rigid_sphere, raw_vv_integral_rigid_sphere
-from .particles import MoleculeSTS
+from .crosssection import raw_vv_integral_fho, raw_vt_integral_fho, raw_vt_integral_rigid_sphere_fho, raw_vv_integral_rigid_sphere_fho
+from .particles import Molecule
 import numpy as np
 
 
-def vt_rate(T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int, rig_sphere: bool=False) -> float:
+def vt_rate(T: float, idata: np.ndarray, molecule: Molecule, i: int, delta: int, rig_sphere: bool=False) -> float:
     """Calculates the VT transition rate constant using the FHO probability and VSS or rigid sphere cross-section models
     for the following process: **M(i) + P -> M(i + delta) + P**
 
@@ -22,7 +22,7 @@ def vt_rate(T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: i
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule which undergoes the VT transition
     i : int
         the vibrational level of the molecule
@@ -46,7 +46,7 @@ def vt_rate(T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: i
                                         molecule.vibr_zero, molecule.diss, i, delta)
 
 
-def vv_rate(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int, k: int, i_delta: int,
+def vv_rate(T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule, i: int, k: int, i_delta: int,
             rig_sphere: bool=False) -> float:
     """Calculates the VV transition rate constant using the FHO probability and VSS or rigid sphere cross-section models
     for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
@@ -57,9 +57,9 @@ def vv_rate(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: Mole
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule1 : MoleculeSTS or Molecule
+    molecule1 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule M1
-    molecule2 : MoleculeSTS or Molecule
+    molecule2 : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule M2
     i : int
         the vibrational level of molecule M1
@@ -123,8 +123,8 @@ def raw_vt_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
         The VT transition rate
 
     """
-    return 8.0 * raw_vt_integral(T, 0, mass, beta, vssc, vsso, ve_before, ve_after,
-                                 molecule_vibr_zero, molecule_diss, i, delta, False)
+    return 8.0 * raw_vt_integral_fho(T, 0, mass, beta, vssc, vsso, ve_before, ve_after,
+                                     molecule_vibr_zero, molecule_diss, i, delta, False)
 
 
 def raw_vt_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float,
@@ -162,8 +162,8 @@ def raw_vt_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float,
         The VT transition rate
 
     """
-    return 8.0 * raw_vt_integral_rigid_sphere(T, 0, sigma, mass, beta, ve_before, ve_after, molecule_vibr_zero,
-                                              molecule_diss, i, delta, False)
+    return 8.0 * raw_vt_integral_rigid_sphere_fho(T, 0, sigma, mass, beta, ve_before, ve_after, molecule_vibr_zero,
+                                                  molecule_diss, i, delta, False)
 
 
 def raw_vv_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
@@ -205,8 +205,8 @@ def raw_vv_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
         The VV transition rate
 
     """
-    return 8.0 * raw_vv_integral(T, 0, mass, beta, vssc, vsso,
-                                 ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta, False)
+    return 8.0 * raw_vv_integral_fho(T, 0, mass, beta, vssc, vsso,
+                                     ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta, False)
 
 
 def raw_vv_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float, ve_before1: float,
@@ -246,5 +246,5 @@ def raw_vv_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float, v
         The VV transition rate
 
     """
-    return 8.0 * raw_vv_integral_rigid_sphere(T, 0, sigma, mass, beta, ve_before1, ve_after1,
-                                              ve_before2, ve_after2, i, k, i_delta, False)
\ No newline at end of file
+    return 8.0 * raw_vv_integral_rigid_sphere_fho(T, 0, sigma, mass, beta, ve_before1, ve_after1,
+                                                  ve_before2, ve_after2, i, k, i_delta, False)
\ No newline at end of file
